@@ -107,10 +107,8 @@ def MagneticDipoleWholeSpace(
 
     orient = kwargs.pop("orientation", None)
     if orient is not None:
-        warnings.warn(
-            "orientation kwarg has been deprecated and will be removed"
-            " in SimPEG version 0.16.0, please use the moment argument",
-            FutureWarning,
+        raise TypeError(
+            "orientation kwarg has been removed, please use the moment argument",
         )
         magnitude = moment
         moment = orient
@@ -118,11 +116,7 @@ def MagneticDipoleWholeSpace(
         magnitude = 1
     mu = kwargs.pop("mu", None)
     if mu is not None:
-        warnings.warn(
-            "mu kwarg has been deprecated and will be removed"
-            " in SimPEG version 0.16.0, please use the mu_r argument.",
-            FutureWarning,
-        )
+        raise TypeError("mu kwarg has been removed, please use the mu_r argument.")
         mu_r = mu / mu_0
 
     mu = mu_0 * mu_r
@@ -196,38 +190,24 @@ def ElectricDipoleWholeSpace(
 
     orient = kwargs.pop("orientation", None)
     if orient is not None:
-        warnings.warn(
-            "orientation kwarg has been deprecated and will be removed"
-            " in SimPEG version 0.16.0, please use the moment argument.",
-            FutureWarning,
+        raise TypeError(
+            "orientation kwarg has been removed, please use the moment argument."
         )
-        moment = orient
     mu = kwargs.pop("mu", None)
     if mu is not None:
-        warnings.warn(
-            "mu kwarg has been deprecated and will be removed"
-            " in SimPEG version 0.16.0, please use the mu_r argument.",
-            FutureWarning,
-        )
-        mu_r = mu / mu_0
+        raise TypeError("mu kwarg has been removed, please use the mu_r argument.")
     cur = kwargs.pop("current", None)
     if cur is not None:
-        warnings.warn(
-            "current kwarg has been deprecated and will be removed"
-            " in SimPEG version 0.16.0, please use the moment argument.",
-            FutureWarning,
+        raise TypeError(
+            "current kwarg has been removed, please use the moment argument.",
         )
-        magnitude = cur
     else:
         magnitude = 1
     length = kwargs.pop("length", None)
     if length is not None:
-        warnings.warn(
-            "length kwarg has been deprecated and will be removed"
-            " in SimPEG version 0.16.0, please use the moment argument.",
-            FutureWarning,
+        raise TypeError(
+            "length kwarg has been removed, please use the moment argument."
         )
-        magnitude *= length
 
     mu = mu_0 * mu_r
     eps = epsilon_0 * eps_r
