@@ -30,7 +30,7 @@ class BaseRx(survey.BaseRx):
         "projComp",
         new_name="orientation",
         removal_version="0.16.0",
-        future_warn=True,
+        error=True,
     )
 
     def __init__(self, locations, orientation=None, component=None, **kwargs):
@@ -188,26 +188,26 @@ class PointCurrentDensity(BaseRx):
 ############
 # Deprecated
 ############
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Point_e(PointElectricField):
     pass
 
 
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Point_b(PointMagneticFluxDensity):
     pass
 
 
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Point_bSecondary(PointMagneticFluxDensitySecondary):
     pass
 
 
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Point_h(PointMagneticField):
     pass
 
 
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Point_j(PointCurrentDensity):
     pass
