@@ -3,7 +3,7 @@ from ..resistivity import receivers, sources
 
 
 def from_dc_to_ip_survey(dc_survey, dim="2.5D"):
-    srcList = dc_survey.source_list
-    ip_survey = Survey(srcList)
+    source_list = dc_survey.source_list
+    ip_survey = Survey(source_list)
 
     return ip_survey
