@@ -27,8 +27,8 @@ class Fields2D(TimeFields):
     .. code-block:: python
 
         f = problem.fields(m)
-        e = f[srcList,'e']
-        j = f[srcList,'j']
+        e = f[source_list,'e']
+        j = f[source_list,'j']
 
     If accessing all sources for a given field, use the
 
@@ -120,10 +120,10 @@ class Fields2D(TimeFields):
             dtype=float,
         )
 
-    def _phi_ky(self, phiSolution, srcList, kyInd):
+    def _phi_ky(self, phiSolution, source_list, kyInd):
         return phiSolution
 
-    def _phi(self, phiSolution, srcList):
+    def _phi(self, phiSolution, source_list):
         return phiSolution.dot(self.simulation._quad_weights)
 
     def _phiDeriv_u(self, kyInd, src, v, adjoint=False):
@@ -255,16 +255,16 @@ Fields2DCellCentred = Fields2DCellCentered
 ############
 # Deprecated
 ############
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Fields_ky(Fields2D):
     pass
 
 
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Fields_ky_CC(Fields2DCellCentered):
     pass
 
 
-@deprecate_class(removal_version="0.16.0", future_warn=True)
+@deprecate_class(removal_version="0.16.0", error=True)
 class Fields_ky_N(Fields2DNodal):
     pass
