@@ -35,7 +35,7 @@ from .tikhonov import *
 #####################################
 
 
-class SimplePGIsmallness(BaseRegularization):
+class PGIsmallness(BaseRegularization):
     """
     Smallness term for the petrophysically constrained regularization (PGI)
     with cell_weights similar to the regularization.tikhonov.SimpleSmall class.
@@ -60,13 +60,15 @@ class SimplePGIsmallness(BaseRegularization):
         mesh=None,
         approx_gradient=True,  # L2 approximate of the gradients
         approx_eval=True,  # L2 approximate of the value
+        approx_hessian=True,
         **kwargs
     ):
 
         self.approx_gradient = approx_gradient
         self.approx_eval = approx_eval
+        self.approx_hessian = approx_hessian
 
-        super(SimplePGIsmallness, self).__init__(mesh=mesh, **kwargs)
+        super(PGIsmallness, self).__init__(mesh=mesh, **kwargs)
         self.gmm = gmm
         self.wiresmap = wiresmap
         self.maplist = maplist
@@ -81,15 +83,28 @@ class SimplePGIsmallness(BaseRegularization):
         Weighting matrix
         Need to change the size to match self.wiresmap.maps * mesh.nC
         """
+
         if self.cell_weights is not None:
             if len(self.cell_weights) == self.wiresmap.nP:
-                return sdiag(np.sqrt(self.cell_weights))
+                return (
+                    sp.kron(
+                        speye(len(self.wiresmap.maps)),
+                        sdiag(np.sqrt(self.regmesh.vol)),
+                    )
+                    * sdiag(np.sqrt(self.cell_weights))
+                )
             else:
                 return sp.kron(
+                    speye(len(self.wiresmap.maps)),
+                    sdiag(np.sqrt(self.regmesh.vol)),
+                ) * sp.kron(
                     speye(len(self.wiresmap.maps)), sdiag(np.sqrt(self.cell_weights))
                 )
         else:
-            return Identity()
+            return sp.kron(
+                speye(len(self.wiresmap.maps)),
+                sdiag(np.sqrt(self.regmesh.vol)),
+            )
 
     @properties.validator("cell_weights")
     def _validate_cell_weights(self, change):
@@ -111,6 +126,14 @@ class SimplePGIsmallness(BaseRegularization):
         model = np.c_[[a * b for a, b in zip(self.maplist, modellist)]].T
         return self.gmm.predict(model)  # mkvc(m, numDims=2))
 
+    def compute_quasi_geology_model(self):
+        # used once mref is built
+        mreflist = self.wiresmap * self.mref
+        mrefarray = np.c_[[a * b for a, b in zip(self.maplist, mreflist)]].T
+        return np.c_[
+            [((mrefarray - mean) ** 2).sum(axis=1) for mean in self.gmm.means_]
+        ].argmin(axis=0)
+
     @timeIt
     def __call__(self, m, externalW=True):
 
@@ -123,7 +146,7 @@ class SimplePGIsmallness(BaseRegularization):
             self.mref = mkvc(self.gmm.means_[self.membership(m)])
 
         if self.approx_eval:
-            membership = self.membership(self.mref)
+            membership = self.compute_quasi_geology_model()
             dm = self.wiresmap * (m)
             dmref = self.wiresmap * (self.mref)
             dmm = np.c_[[a * b for a, b in zip(self.maplist, dm)]].T
@@ -181,7 +204,7 @@ class SimplePGIsmallness(BaseRegularization):
         if getattr(self, "mref", None) is None:
             self.mref = mkvc(self.gmm.means_[self.membership(m)])
 
-        membership = self.membership(self.mref)
+        membership = self.compute_quasi_geology_model()
         modellist = self.wiresmap * m
         mreflist = self.wiresmap * self.mref
         mD = [a.deriv(b) for a, b in zip(self.maplist, modellist)]
@@ -327,9 +350,8 @@ class SimplePGIsmallness(BaseRegularization):
                     )
             W = np.c_[W].T
             logP = np.vstack([logP for maps in self.wiresmap.maps])
-            numer, sign = logsumexp(logP, axis=1, b=W, return_sign=True)
-            logderiv = numer - score_vec
-            r = sign * np.exp(logderiv)
+            numer = (W * np.exp(logP)).sum(axis=1)
+            r = numer / (np.exp(score_vec))
             return mkvc(mD.T * r)
 
     @timeIt
@@ -338,298 +360,142 @@ class SimplePGIsmallness(BaseRegularization):
         if getattr(self, "mref", None) is None:
             self.mref = mkvc(self.gmm.means_[self.membership(m)])
 
-        # For a positive definite Hessian,
-        # we approximate it with the covariance of the cluster
-        # whose each point belong
-        membership = self.membership(self.mref)
-        modellist = self.wiresmap * m
-        mD = [a.deriv(b) for a, b in zip(self.maplist, modellist)]
-        mD = sp.block_diag(mD)
+        if self.approx_hessian:
+            # we approximate it with the covariance of the cluster
+            # whose each point belong
+            membership = self.compute_quasi_geology_model()
+            modellist = self.wiresmap * m
+            mD = [a.deriv(b) for a, b in zip(self.maplist, modellist)]
+            mD = sp.block_diag(mD)
 
-        if self.gmm.covariance_type == "tied":
-            r = self.gmm.precisions_[np.newaxis, :, :][np.zeros_like(membership)]
-        elif (
-            self.gmm.covariance_type == "spherical"
-            or self.gmm.covariance_type == "diag"
-        ):
-            r = np.r_[
-                [
-                    self.gmm.precisions_[memb] * np.eye(len(self.wiresmap.maps))
-                    for memb in membership
+            if self.gmm.covariance_type == "tied":
+                r = self.gmm.precisions_[np.newaxis, :, :][np.zeros_like(membership)]
+            elif (
+                self.gmm.covariance_type == "spherical"
+                or self.gmm.covariance_type == "diag"
+            ):
+                r = np.r_[
+                    [
+                        self.gmm.precisions_[memb] * np.eye(len(self.wiresmap.maps))
+                        for memb in membership
+                    ]
                 ]
-            ]
-        else:
-            r = self.gmm.precisions_[membership]
+            else:
+                r = self.gmm.precisions_[membership]
 
-        if v is not None:
-            mDv = self.wiresmap * (mD * v)
-            mDv = np.c_[mDv]
-            r0 = (self.W * (mkvc(mDv))).reshape(mDv.shape, order="F")
-            return mkvc(
-                mD.T
-                * (
-                    self.W
-                    * (mkvc(np.r_[[np.dot(r[i], r0[i]) for i in range(len(r0))]]))
+            if v is not None:
+                mDv = self.wiresmap * (mD * v)
+                mDv = np.c_[mDv]
+                r0 = (self.W * (mkvc(mDv))).reshape(mDv.shape, order="F")
+                return mkvc(
+                    mD.T
+                    * (
+                        self.W
+                        * (mkvc(np.r_[[np.dot(r[i], r0[i]) for i in range(len(r0))]]))
+                    )
                 )
-            )
+            else:
+                # Forming the Hessian by diagonal blocks
+                hlist = [
+                    [r[:, i, j] for i in range(len(self.wiresmap.maps))]
+                    for j in range(len(self.wiresmap.maps))
+                ]
+                Hr = sp.csc_matrix((0, 0), dtype=np.float64)
+                for i in range(len(self.wiresmap.maps)):
+                    Hc = sp.csc_matrix((0, 0), dtype=np.float64)
+                    for j in range(len(self.wiresmap.maps)):
+                        Hc = sp.hstack([Hc, sdiag(hlist[i][j])])
+                    Hr = sp.vstack([Hr, Hc])
+
+                Hr = Hr.dot(self.W)
+
+                return (mD.T * mD) * (self.W * (Hr))
+
         else:
-            # Forming the Hessian by diagonal blocks
+            # non distinct clusters positive definite approximated Hessian
+            modellist = self.wiresmap * m
+            model = np.c_[[a * b for a, b in zip(self.maplist, modellist)]].T
+
+            if getattr(self.W, "diagonal", None) is not None:
+                sensW = np.c_[
+                    [wire[1] * self.W.diagonal() for wire in self.wiresmap.maps]
+                ].T
+            else:
+                sensW = np.ones_like(model)
+
+            mD = [a.deriv(b) for a, b in zip(self.maplist, modellist)]
+            mD = sp.block_diag(mD)
+
+            score = self.gmm.score_samples_with_sensW(model, sensW)
+            logP = np.zeros((len(model), self.gmm.n_components))
+            W = []
+            logP = self.gmm._estimate_weighted_log_prob_with_sensW(
+                model,
+                sensW,
+            )
+            for k in range(self.gmm.n_components):
+                if self.gmm.covariance_type == "tied":
+
+                    W.append(
+                        [
+                            np.diag(sensW[i]).dot(
+                                self.gmm.precisions_.dot(np.diag(sensW[i]))
+                            )
+                            for i in range(len(model))
+                        ]
+                    )
+                elif (
+                    self.gmm.covariance_type == "diag"
+                    or self.gmm.covariance_type == "spherical"
+                ):
+                    W.append(
+                        [
+                            np.diag(sensW[i]).dot(
+                                (
+                                    self.gmm.precisions_[k]
+                                    * np.eye(len(self.wiresmap.maps))
+                                ).dot(np.diag(sensW[i]))
+                            )
+                            for i in range(len(model))
+                        ]
+                    )
+                else:
+                    W.append(
+                        [
+                            np.diag(sensW[i]).dot(
+                                self.gmm.precisions_[k].dot(np.diag(sensW[i]))
+                            )
+                            for i in range(len(model))
+                        ]
+                    )
+            W = np.c_[W]
+
             hlist = [
-                [r[:, i, j] for i in range(len(self.wiresmap.maps))]
+                [
+                    (W[:, :, i, j].T * np.exp(logP)).sum(axis=1) / np.exp(score)
+                    for i in range(len(self.wiresmap.maps))
+                ]
                 for j in range(len(self.wiresmap.maps))
             ]
 
+            # Forming the Hessian by diagonal blocks
             Hr = sp.csc_matrix((0, 0), dtype=np.float64)
             for i in range(len(self.wiresmap.maps)):
                 Hc = sp.csc_matrix((0, 0), dtype=np.float64)
                 for j in range(len(self.wiresmap.maps)):
                     Hc = sp.hstack([Hc, sdiag(hlist[i][j])])
                 Hr = sp.vstack([Hr, Hc])
+            Hr = (mD.T * mD) * Hr
 
-            Hr = Hr.dot(self.W)
-            # mDW = self.W * mD
-
-            return (mD.T * mD) * (self.W * (Hr))
-
-
-class SimplePGI(SimpleComboRegularization):
-    """
-    class similar to regularization.tikhonov.Simple, with a SimplePGIsmallness.
-    PARAMETERS
-    ----------
-    :param SimPEG.utils.WeightedGaussianMixture gmmref: refereence/prior GMM
-    :param SimPEG.utils.WeightedGaussianMixture gmm: GMM to use
-    :param SimPEG.maps.Wires wiresmap: wires mapping to the various physical properties
-    :param list maplist: list of SimPEG.maps for each physical property.
-    :param discretize.BaseMesh mesh: tensor, QuadTree or Octree mesh
-    :param boolean approx_gradient: use the L2-approximation of the gradient, default is True
-    :param boolean approx_eval: use the L2-approximation evaluation of the smallness term
-    """
-
-    def __init__(
-        self,
-        mesh,
-        gmmref,
-        gmm=None,
-        wiresmap=None,
-        maplist=None,
-        approx_gradient=True,
-        approx_eval=True,
-        alpha_s=1.0,
-        alpha_x=1.0,
-        alpha_y=1.0,
-        alpha_z=1.0,
-        alpha_xx=0.0,
-        alpha_yy=0.0,
-        alpha_zz=0.0,
-        **kwargs
-    ):
-        self.gmmref = copy.deepcopy(gmmref)
-        self.gmmref.order_clusters_GM_weight()
-        self._gmm = copy.deepcopy(gmm)
-        self._wiresmap = wiresmap
-        self._maplist = maplist
-        self._mesh = mesh
-        self.mesh = mesh
-        self._approx_gradient = approx_gradient
-        self._approx_eval = approx_eval
-        self.mapping = IdentityMap(mesh, nP=self.wiresmap.nP)
-
-        objfcts = [
-            SimplePGIsmallness(
-                mesh=mesh,
-                gmm=self.gmm,
-                wiresmap=self.wiresmap,
-                maplist=self.maplist,
-                approx_gradient=approx_gradient,
-                approx_eval=approx_eval,
-                mapping=self.mapping,
-                **kwargs
-            )
-        ]
-        objfcts += [
-            SimpleSmoothDeriv(
-                mesh=mesh, orientation="x", mapping=maps * wire[1], **kwargs
-            )
-            for wire, maps in zip(self._wiresmap.maps, self._maplist)
-        ]
-        objfcts += [
-            SmoothDeriv2(mesh=mesh, orientation="x", mapping=maps * wire[1], **kwargs)
-            for wire, maps in zip(self._wiresmap.maps, self._maplist)
-        ]
-
-        if mesh.dim > 1:
-            objfcts += [
-                SimpleSmoothDeriv(
-                    mesh=mesh, orientation="y", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-            objfcts += [
-                SmoothDeriv2(
-                    mesh=mesh, orientation="y", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-
-        if mesh.dim > 2:
-            objfcts += [
-                SimpleSmoothDeriv(
-                    mesh=mesh, orientation="z", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-            objfcts += [
-                SmoothDeriv2(
-                    mesh=mesh, orientation="z", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-
-        super(SimplePGI, self).__init__(
-            mesh=mesh,
-            alpha_s=alpha_s,
-            alpha_x=alpha_x,
-            alpha_y=alpha_y,
-            alpha_z=alpha_z,
-            alpha_xx=alpha_xx,
-            alpha_yy=alpha_yy,
-            alpha_zz=alpha_zz,
-            objfcts=objfcts,
-            **kwargs
-        )
-
-    # Properties
-    alpha_s = props.Float("PGI smallness multiplier")
-
-    @property
-    def gmm(self):
-        if getattr(self, "_gmm", None) is None:
-            self._gmm = copy.deepcopy(self.gmmref)
-        return self._gmm
-
-    @gmm.setter
-    def gmm(self, gm):
-        if gm is not None:
-            self._gmm = copy.deepcopy(gm)
-        self.objfcts[0].gmm = self.gmm
-
-    def membership(self, m):
-        return self.objfcts[0].membership(m)
-
-    @property
-    def wiresmap(self):
-        if getattr(self, "_wiresmap", None) is None:
-            self._wiresmap = Wires(("m", self._mesh.nC))
-        return self._wiresmap
-
-    @wiresmap.setter
-    def wiresmap(self, wm):
-        if wm is not None:
-            self._wiresmap = wm
-        self.objfcts[0].wiresmap = self.wiresmap
-
-    @property
-    def maplist(self):
-        if getattr(self, "_maplist", None) is None:
-            self._maplist = [IdentityMap(self._mesh) for maps in self.wiresmap.maps]
-        return self._maplist
-
-    @maplist.setter
-    def maplist(self, mp):
-        if mp is not None:
-            self._maplist = mp
-        self.objfcts[0].maplist = self.maplist
-
-    @property
-    def approx_gradient(self):
-        if getattr(self, "_approx_gradient", None) is None:
-            self._approx_gradient = True
-        return self._approx_gradient
-
-    @approx_gradient.setter
-    def approx_gradient(self, ap):
-        if ap is not None:
-            self._approx_gradient = ap
-        self.objfcts[0].approx_gradient = self.approx_gradient
-
-    @property
-    def approx_eval(self):
-        if getattr(self, "_approx_eval", None) is None:
-            self._approx_eval = True
-        return self._approx_eval
-
-    @approx_eval.setter
-    def approx_eval(self, ap):
-        if ap is not None:
-            self._approx_eval = ap
-        self.objfcts[0].approx_eval = self.approx_eval
-
-
-class PGIsmallness(SimplePGIsmallness):
-    """
-    Smallness term for the petrophysically constrained regularization (PGI) with
-    cell_weights similar to the ones used in regularization.tikhonov.Tikhonov
-
-    PARAMETERS
-    ----------
-    :param SimPEG.utils.WeightedGaussianMixture gmm: GMM to use
-    :param SimPEG.maps.Wires wiresmap: wires mapping to the various physical properties
-    :param list maplist: list of SimPEG.maps for each physical property.
-    :param discretize.BaseMesh mesh: tensor, QuadTree or Octree mesh
-    :param boolean approx_gradient: use the L2-approximation of the gradient, default is True
-    :param boolean approx_eval: use the L2-approximation evaluation of the smallness term
-    """
-
-    _multiplier_pair = "alpha_s"
-
-    def __init__(
-        self,
-        gmm,
-        wiresmap=None,
-        maplist=None,
-        mesh=None,
-        approx_gradient=True,
-        approx_eval=True,
-        **kwargs
-    ):
-
-        super(PGIsmallness, self).__init__(
-            gmm=gmm,
-            wiresmap=wiresmap,
-            maplist=maplist,
-            mesh=mesh,
-            approx_gradient=True,
-            approx_eval=approx_eval,
-            **kwargs
-        )
-
-    @property
-    def W(self):
-        """
-        Weighting matrix
-        Need to change the size to match self.wiresmap.maps * mesh.nC
-        """
-        if self.cell_weights is not None:
-            if len(self.cell_weights) == self.wiresmap.nP:
-                return sp.kron(
-                    speye(len(self.wiresmap.maps)), sdiag(np.sqrt(self.regmesh.vol)),
-                ) * sdiag(np.sqrt(self.cell_weights))
+            if v is not None:
+                return Hr.dot(v)
             else:
-                return sp.kron(
-                    speye(len(self.wiresmap.maps)), sdiag(np.sqrt(self.regmesh.vol)),
-                ) * sp.kron(
-                    speye(len(self.wiresmap.maps)), sdiag(np.sqrt(self.cell_weights))
-                )
-        else:
-            return sp.kron(
-                speye(len(self.wiresmap.maps)), sdiag(np.sqrt(self.regmesh.vol)),
-            )
+                return Hr
 
 
 class PGI(SimpleComboRegularization):
     """
-    class similar to regularization.tikhonov.Simple, with a SimplePGIsmallness.
+    class similar to regularization.tikhonov.Simple, with a PGIsmallness.
     PARAMETERS
     ----------
     :param SimPEG.utils.WeightedGaussianMixture gmmref: refereence/prior GMM
@@ -648,6 +514,7 @@ class PGI(SimpleComboRegularization):
         gmm=None,
         wiresmap=None,
         maplist=None,
+        approx_hessian=True,
         approx_gradient=True,
         approx_eval=True,
         alpha_s=1.0,
@@ -666,6 +533,7 @@ class PGI(SimpleComboRegularization):
         self._maplist = maplist
         self._mesh = mesh
         self.mesh = mesh
+        self._approx_hessian = approx_hessian
         self._approx_gradient = approx_gradient
         self._approx_eval = approx_eval
         self.mapping = IdentityMap(mesh, nP=self.wiresmap.nP)
@@ -682,42 +550,6 @@ class PGI(SimpleComboRegularization):
                 **kwargs
             )
         ]
-        objfcts += [
-            SmoothDeriv(mesh=mesh, orientation="x", mapping=maps * wire[1], **kwargs)
-            for wire, maps in zip(self._wiresmap.maps, self._maplist)
-        ]
-        objfcts += [
-            SmoothDeriv2(mesh=mesh, orientation="x", mapping=maps * wire[1], **kwargs)
-            for wire, maps in zip(self._wiresmap.maps, self._maplist)
-        ]
-
-        if mesh.dim > 1:
-            objfcts += [
-                SmoothDeriv(
-                    mesh=mesh, orientation="y", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-            objfcts += [
-                SmoothDeriv2(
-                    mesh=mesh, orientation="y", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-
-        if mesh.dim > 2:
-            objfcts += [
-                SmoothDeriv(
-                    mesh=mesh, orientation="z", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-            objfcts += [
-                SmoothDeriv2(
-                    mesh=mesh, orientation="z", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
 
         super(PGI, self).__init__(
             mesh=mesh,
@@ -750,6 +582,9 @@ class PGI(SimpleComboRegularization):
     def membership(self, m):
         return self.objfcts[0].membership(m)
 
+    def compute_quasi_geology_model(self):
+        return self.objfcts[0].compute_quasi_geology_model()
+
     @property
     def wiresmap(self):
         if getattr(self, "_wiresmap", None) is None:
@@ -780,6 +615,18 @@ class PGI(SimpleComboRegularization):
             self._approx_gradient = True
         return self._approx_gradient
 
+    @property
+    def approx_hessian(self):
+        if getattr(self, "_approx_hessian", None) is None:
+            self._approx_hessian = True
+        return self._approx_hessian
+
+    @approx_hessian.setter
+    def approx_hessian(self, ap):
+        if ap is not None:
+            self._approx_hessian = ap
+        self.objfcts[0].approx_hessian = self.approx_hessian
+
     @approx_gradient.setter
     def approx_gradient(self, ap):
         if ap is not None:
@@ -799,7 +646,7 @@ class PGI(SimpleComboRegularization):
         self.objfcts[0].approx_eval = self.approx_eval
 
 
-class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
+class PGIwithNonlinearRelationshipsSmallness(BaseRegularization):
     """
     Smallness term for the petrophysically constrained regularization (PGI) with
     nonlinear relationships between physical properties and cells_weight s
@@ -831,7 +678,7 @@ class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
         self.approx_gradient = approx_gradient
         self.approx_eval = approx_eval
 
-        super(SimplePGIwithNonlinearRelationshipsSmallness, self).__init__(
+        super(PGIwithNonlinearRelationshipsSmallness, self).__init__(
             mesh=mesh, **kwargs
         )
         self.gmm = gmm
@@ -848,15 +695,28 @@ class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
         Weighting matrix
         Need to change the size to match self.wiresmap.maps * mesh.nC
         """
+
         if self.cell_weights is not None:
             if len(self.cell_weights) == self.wiresmap.nP:
-                return sdiag(np.sqrt(self.cell_weights))
+                return (
+                    sp.kron(
+                        speye(len(self.wiresmap.maps)),
+                        sdiag(np.sqrt(self.regmesh.vol)),
+                    )
+                    * sdiag(np.sqrt(self.cell_weights))
+                )
             else:
                 return sp.kron(
+                    speye(len(self.wiresmap.maps)),
+                    sdiag(np.sqrt(self.regmesh.vol)),
+                ) * sp.kron(
                     speye(len(self.wiresmap.maps)), sdiag(np.sqrt(self.cell_weights))
                 )
         else:
-            return Identity()
+            return sp.kron(
+                speye(len(self.wiresmap.maps)),
+                sdiag(np.sqrt(self.regmesh.vol)),
+            )
 
     @properties.validator("cell_weights")
     def _validate_cell_weights(self, change):
@@ -878,6 +738,14 @@ class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
         model = np.c_[[a * b for a, b in zip(self.maplist, modellist)]].T
         return self.gmm.predict(model)
 
+    def compute_quasi_geology_model(self):
+        # used once mref is built
+        mreflist = self.wiresmap * self.mref
+        mrefarray = np.c_[[a * b for a, b in zip(self.maplist, mreflist)]].T
+        return np.c_[
+            [((mrefarray - mean) ** 2).sum(axis=1) for mean in self.gmm.means_]
+        ].argmin(axis=0)
+
     @timeIt
     def __call__(self, m, externalW=True):
 
@@ -890,7 +758,7 @@ class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
             self.mref = mkvc(self.gmm.means_[self.membership(m)])
 
         if self.approx_eval:
-            membership = self.membership(self.mref)
+            membership = self.compute_quasi_geology_model()
             dm = self.wiresmap * (m)
             dmref = self.wiresmap * (self.mref)
             dmm = np.c_[[a * b for a, b in zip(self.maplist, dm)]].T
@@ -948,7 +816,7 @@ class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
         if getattr(self, "mref", None) is None:
             self.mref = mkvc(self.gmm.means_[self.membership(m)])
 
-        membership = self.membership(self.mref)
+        membership = self.compute_quasi_geology_model()
         modellist = self.wiresmap * m
         dmmodel = np.c_[[a * b for a, b in zip(self.maplist, modellist)]].T
         mreflist = self.wiresmap * self.mref
@@ -997,7 +865,7 @@ class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
         # For a positive definite Hessian,
         # we approximate it with the covariance of the cluster
         # whose each point belong
-        membership = self.membership(self.mref)
+        membership = self.compute_quasi_geology_model()
         modellist = self.wiresmap * m
         dmmodel = np.c_[[a * b for a, b in zip(self.maplist, modellist)]].T
         mD = [a.deriv(b) for a, b in zip(self.maplist, modellist)]
@@ -1089,10 +957,10 @@ class SimplePGIwithNonlinearRelationshipsSmallness(BaseRegularization):
             return (mDW.T * mDW) * Hr
 
 
-class SimplePGIwithRelationships(SimpleComboRegularization):
+class PGIwithRelationships(SimpleComboRegularization):
     """
     class similar to regularization.tikhonov.Simple, with a
-    SimplePGIwithNonlinearRelationshipsSmallness.
+    PGIwithNonlinearRelationshipsSmallness.
 
     PARAMETERS
     ----------
@@ -1135,7 +1003,7 @@ class SimplePGIwithRelationships(SimpleComboRegularization):
         self.mapping = IdentityMap(mesh, nP=self.wiresmap.nP)
 
         objfcts = [
-            SimplePGIwithNonlinearRelationshipsSmallness(
+            PGIwithNonlinearRelationshipsSmallness(
                 mesh=mesh,
                 gmm=self.gmm,
                 wiresmap=self.wiresmap,
@@ -1146,46 +1014,8 @@ class SimplePGIwithRelationships(SimpleComboRegularization):
                 **kwargs
             )
         ]
-        objfcts += [
-            SimpleSmoothDeriv(
-                mesh=mesh, orientation="x", mapping=maps * wire[1], **kwargs
-            )
-            for wire, maps in zip(self._wiresmap.maps, self._maplist)
-        ]
-        objfcts += [
-            SmoothDeriv2(mesh=mesh, orientation="x", mapping=maps * wire[1], **kwargs)
-            for wire, maps in zip(self._wiresmap.maps, self._maplist)
-        ]
 
-        if mesh.dim > 1:
-            objfcts += [
-                SimpleSmoothDeriv(
-                    mesh=mesh, orientation="y", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-            objfcts += [
-                SmoothDeriv2(
-                    mesh=mesh, orientation="y", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-
-        if mesh.dim > 2:
-            objfcts += [
-                SimpleSmoothDeriv(
-                    mesh=mesh, orientation="z", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-            objfcts += [
-                SmoothDeriv2(
-                    mesh=mesh, orientation="z", mapping=maps * wire[1], **kwargs
-                )
-                for wire, maps in zip(self._wiresmap.maps, self._maplist)
-            ]
-
-        super(SimplePGIwithRelationships, self).__init__(
+        super(PGIwithRelationships, self).__init__(
             mesh=mesh,
             alpha_s=alpha_s,
             alpha_x=alpha_x,
@@ -1217,6 +1047,9 @@ class SimplePGIwithRelationships(SimpleComboRegularization):
     def membership(self, m):
         return self.objfcts[0].membership(m)
 
+    def compute_quasi_geology_model(self):
+        return self.objfcts[0].compute_quasi_geology_model()
+
     @property
     def wiresmap(self):
         if getattr(self, "_wiresmap", None) is None:
