@@ -19,7 +19,7 @@ class RegularizationMesh(props.BaseSimPEG):
 
     This contains the operators used in the regularization. Note that these
     are not necessarily true differential operators, but are constructed from
-    a SimPEG Mesh.
+    a `discretize` Mesh.
 
     :param discretize.base.BaseMesh mesh: problem mesh
     :param numpy.ndarray indActive: bool array, size nC, that is True where we have active cells. Used to reduce the operators so we regularize only on active cells
@@ -106,22 +106,20 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: active face-x projection matrix
         """
         if getattr(self, "_Pafx", None) is None:
-            if self.indActive is None:
-                self._Pafx = utils.speye(self.mesh.nFx)
+            # if getattr(self.mesh, 'aveCC2Fx', None) is not None:
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                ind_active = self.indActive
+                if ind_active is None:
+                    ind_active = np.ones(self.mesh.nC, dtype="bool")
+                indActive_Fx = (
+                    self.mesh.average_cell_to_total_face_x() * ind_active
+                ) >= 1
+                self._Pafx = utils.speye(self.mesh.ntFx)[:, indActive_Fx]
             else:
-                # if getattr(self.mesh, 'aveCC2Fx', None) is not None:
-                if self.mesh._meshType == "TREE":
-                    if self.regularization_type == "Tikhonov":
-                        indActive_Fx = (self.mesh.aveFx2CC.T * self.indActive) >= 1
-                        self._Pafx = utils.speye(self.mesh.nFx)[:, indActive_Fx]
-                    else:
-                        indActive_Fx = (
-                            self.mesh._aveCC2FxStencil() * self.indActive
-                        ) >= 1
-                        self._Pafx = utils.speye(self.mesh.ntFx)[:, indActive_Fx]
+                if self.indActive is None:
+                    self._Pafx = utils.speye(self.mesh.nFx)
                 else:
                     indActive_Fx = self.mesh.aveFx2CC.T * self.indActive >= 1
-
                     self._Pafx = utils.speye(self.mesh.nFx)[:, indActive_Fx]
         return self._Pafx
 
@@ -135,19 +133,17 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: active face-y projection matrix
         """
         if getattr(self, "_Pafy", None) is None:
-            if self.indActive is None:
-                self._Pafy = utils.speye(self.mesh.nFy)
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                ind_active = self.indActive
+                if ind_active is None:
+                    ind_active = np.ones(self.mesh.nC, dtype="bool")
+                indActive_Fy = (
+                    self.mesh.average_cell_to_total_face_y() * ind_active
+                ) >= 1
+                self._Pafy = utils.speye(self.mesh.ntFy)[:, indActive_Fy]
             else:
-                # if getattr(self.mesh, 'aveCC2Fy', None) is not None:
-                if self.mesh._meshType == "TREE":
-                    if self.regularization_type == "Tikhonov":
-                        indActive_Fy = (self.mesh.aveFy2CC.T * self.indActive) >= 1
-                        self._Pafy = utils.speye(self.mesh.nFy)[:, indActive_Fy]
-                    else:
-                        indActive_Fy = (
-                            self.mesh._aveCC2FyStencil() * self.indActive
-                        ) >= 1
-                        self._Pafy = utils.speye(self.mesh.ntFy)[:, indActive_Fy]
+                if self.indActive is None:
+                    self._Pafy = utils.speye(self.mesh.nFy)
                 else:
                     indActive_Fy = (self.mesh.aveFy2CC.T * self.indActive) >= 1
                     self._Pafy = utils.speye(self.mesh.nFy)[:, indActive_Fy]
@@ -163,24 +159,31 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: active face-z projection matrix
         """
         if getattr(self, "_Pafz", None) is None:
-            if self.indActive is None:
-                self._Pafz = utils.speye(self.mesh.nFz)
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                ind_active = self.indActive
+                if ind_active is None:
+                    ind_active = np.ones(self.mesh.nC, dtype="bool")
+                indActive_Fz = (
+                    self.mesh.average_cell_to_total_face_z() * ind_active
+                ) >= 1
+                self._Pafz = utils.speye(self.mesh.ntFz)[:, indActive_Fz]
             else:
-                # if getattr(self.mesh, 'aveCC2Fz', None) is not None:
-                if self.mesh._meshType == "TREE":
-                    if self.regularization_type == "Tikhonov":
-                        indActive_Fz = (self.mesh.aveFz2CC.T * self.indActive) >= 1
-                        self._Pafz = utils.speye(self.mesh.nFz)[:, indActive_Fz]
-                    else:
-                        indActive_Fz = (
-                            self.mesh._aveCC2FzStencil() * self.indActive
-                        ) >= 1
-                        self._Pafz = utils.speye(self.mesh.ntFz)[:, indActive_Fz]
+                if self.indActive is None:
+                    self._Pafz = utils.speye(self.mesh.nFz)
                 else:
                     indActive_Fz = (self.mesh.aveFz2CC.T * self.indActive) >= 1
                     self._Pafz = utils.speye(self.mesh.nFz)[:, indActive_Fz]
         return self._Pafz
 
+    @property
+    def average_face_to_cell(self):
+        if self.dim == 1:
+            return self.aveFx2CC
+        elif self.dim == 2:
+            return sp.hstack([self.aveFx2CC, self.aveFy2CC])
+        else:
+            return sp.hstack([self.aveFx2CC, self.aveFy2CC, self.aveFz2CC])
+
     @property
     def aveFx2CC(self):
         """
@@ -190,14 +193,10 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: averaging from active cell centers to active x-faces
         """
         if getattr(self, "_aveFx2CC", None) is None:
-            if self.mesh._meshType == "TREE":
-                if self.regularization_type == "Tikhonov":
-                    self._aveFx2CC = self.Pac.T * self.mesh.aveFx2CC * self.Pafx
-
-                else:
-                    nCinRow = utils.mkvc((self.aveCC2Fx.T).sum(1))
-                    nCinRow[nCinRow > 0] = 1.0 / nCinRow[nCinRow > 0]
-                    self._aveFx2CC = utils.sdiag(nCinRow) * self.aveCC2Fx.T
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                nCinRow = utils.mkvc((self.aveCC2Fx.T).sum(1))
+                nCinRow[nCinRow > 0] = 1.0 / nCinRow[nCinRow > 0]
+                self._aveFx2CC = utils.sdiag(nCinRow) * self.aveCC2Fx.T
 
             else:
                 self._aveFx2CC = self.Pac.T * self.mesh.aveFx2CC * self.Pafx
@@ -213,17 +212,10 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: averaging matrix from active x-faces to active cell centers
         """
         if getattr(self, "_aveCC2Fx", None) is None:
-
-            # if getattr(self.mesh, 'aveCC2Fx', None) is not None:
-            if self.mesh._meshType == "TREE":
-                if self.regularization_type == "Tikhonov":
-                    self._aveCC2Fx = (
-                        utils.sdiag(1.0 / (self.aveFx2CC.T).sum(1)) * self.aveFx2CC.T
-                    )
-                else:
-                    self._aveCC2Fx = (
-                        self.Pafx.T * self.mesh._aveCC2FxStencil() * self.Pac
-                    )
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                self._aveCC2Fx = (
+                    self.Pafx.T * self.mesh.average_cell_to_total_face_x() * self.Pac
+                )
             else:
                 self._aveCC2Fx = (
                     utils.sdiag(1.0 / (self.aveFx2CC.T).sum(1)) * self.aveFx2CC.T
@@ -239,15 +231,10 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: averaging from active cell centers to active y-faces
         """
         if getattr(self, "_aveFy2CC", None) is None:
-            if self.mesh._meshType == "TREE":
-                if self.regularization_type == "Tikhonov":
-                    self._aveFy2CC = self.Pac.T * self.mesh.aveFy2CC * self.Pafy
-
-                else:
-                    nCinRow = utils.mkvc((self.aveCC2Fy.T).sum(1))
-                    nCinRow[nCinRow > 0] = 1.0 / nCinRow[nCinRow > 0]
-                    self._aveFy2CC = utils.sdiag(nCinRow) * self.aveCC2Fy.T
-
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                nCinRow = utils.mkvc((self.aveCC2Fy.T).sum(1))
+                nCinRow[nCinRow > 0] = 1.0 / nCinRow[nCinRow > 0]
+                self._aveFy2CC = utils.sdiag(nCinRow) * self.aveCC2Fy.T
             else:
                 self._aveFy2CC = self.Pac.T * self.mesh.aveFy2CC * self.Pafy
 
@@ -262,16 +249,10 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: averaging matrix from active y-faces to active cell centers
         """
         if getattr(self, "_aveCC2Fy", None) is None:
-            # if getattr(self.mesh, 'aveCC2Fy', None) is not None:
-            if self.mesh._meshType == "TREE":
-                if self.regularization_type == "Tikhonov":
-                    self._aveCC2Fy = (
-                        utils.sdiag(1.0 / (self.aveFy2CC.T).sum(1)) * self.aveFy2CC.T
-                    )
-                else:
-                    self._aveCC2Fy = (
-                        self.Pafy.T * self.mesh._aveCC2FyStencil() * self.Pac
-                    )
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                self._aveCC2Fy = (
+                    self.Pafy.T * self.mesh.average_cell_to_total_face_y() * self.Pac
+                )
             else:
                 self._aveCC2Fy = (
                     utils.sdiag(1.0 / (self.aveFy2CC.T).sum(1)) * self.aveFy2CC.T
@@ -287,15 +268,10 @@ class RegularizationMesh(props.BaseSimPEG):
         :return: averaging from active cell centers to active z-faces
         """
         if getattr(self, "_aveFz2CC", None) is None:
-            if self.mesh._meshType == "TREE":
-                if self.regularization_type == "Tikhonov":
-                    self._aveFz2CC = self.Pac.T * self.mesh.aveFz2CC * self.Pafz
-
-                else:
-                    nCinRow = utils.mkvc((self.aveCC2Fz.T).sum(1))
-                    nCinRow[nCinRow > 0] = 1.0 / nCinRow[nCinRow > 0]
-                    self._aveFz2CC = utils.sdiag(nCinRow) * self.aveCC2Fz.T
-
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                nCinRow = utils.mkvc((self.aveCC2Fz.T).sum(1))
+                nCinRow[nCinRow > 0] = 1.0 / nCinRow[nCinRow > 0]
+                self._aveFz2CC = utils.sdiag(nCinRow) * self.aveCC2Fz.T
             else:
                 self._aveFz2CC = self.Pac.T * self.mesh.aveFz2CC * self.Pafz
 
@@ -311,21 +287,25 @@ class RegularizationMesh(props.BaseSimPEG):
         """
         if getattr(self, "_aveCC2Fz", None) is None:
             # if getattr(self.mesh, 'aveCC2Fz', None) is not None:
-            if self.mesh._meshType == "TREE":
-                if self.regularization_type == "Tikhonov":
-                    self._aveCC2Fz = (
-                        utils.sdiag(1.0 / (self.aveFz2CC.T).sum(1)) * self.aveFz2CC.T
-                    )
-                else:
-                    self._aveCC2Fz = (
-                        self.Pafz.T * self.mesh._aveCC2FzStencil() * self.Pac
-                    )
+            if self.mesh._meshType == "TREE" and self.regularization_type != "Tikhonov":
+                self._aveCC2Fz = (
+                    self.Pafz.T * self.mesh.average_cell_to_total_face_z() * self.Pac
+                )
             else:
                 self._aveCC2Fz = (
                     utils.sdiag(1.0 / (self.aveFz2CC.T).sum(1)) * self.aveFz2CC.T
                 )
         return self._aveCC2Fz
 
+    @property
+    def cell_gradient(self):
+        if self.dim == 1:
+            return self.cellDiffx
+        elif self.dim == 2:
+            return sp.vstack([self.cellDiffx, self.cellDiffy])
+        else:
+            return sp.vstack([self.cellDiffx, self.cellDiffy, self.cellDiffz])
+
     @property
     def cellDiffx(self):
         """
