@@ -1,5 +1,5 @@
 from .code_utils import deprecate_module
 
-deprecate_module("coordutils", "coord_utils", "0.16.0", future_warn=True)
+deprecate_module("coordutils", "coord_utils", "0.16.0", error=True)
 
 from .coord_utils import *
